==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/UISearchDisplayDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UISearchDisplayDelegateAdapter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*/implements UISearchDisplayDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayControllerWillBeginSearch:")
    public void willBeginSearch(UISearchDisplayController controller) {}
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayControllerDidBeginSearch:")
    public void didBeginSearch(UISearchDisplayController controller) {}
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayControllerWillEndSearch:")
    public void willEndSearch(UISearchDisplayController controller) {}
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayControllerDidEndSearch:")
    public void didEndSearch(UISearchDisplayController controller) {}
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:didLoadSearchResultsTableView:")
    public void didLoadSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:willUnloadSearchResultsTableView:")
    public void willUnloadSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:willShowSearchResultsTableView:")
    public void willShowSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:didShowSearchResultsTableView:")
    public void didShowSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:willHideSearchResultsTableView:")
    public void willHideSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:didHideSearchResultsTableView:")
    public void didHideSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:shouldReloadTableForSearchString:")
    public boolean shouldReloadForSearchString(UISearchDisplayController controller, String searchString) { return false; }
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:shouldReloadTableForSearchScope:")
    public boolean shouldReloadForSearchScope(UISearchDisplayController controller, @MachineSizedSInt long searchOption) { return false; }
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/uikit/UISearchDisplayDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UISearchDisplayDelegateAdapter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*/implements UISearchDisplayDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayControllerWillBeginSearch:")
    public void willBeginSearch(UISearchDisplayController controller) {}
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayControllerDidBeginSearch:")
    public void didBeginSearch(UISearchDisplayController controller) {}
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayControllerWillEndSearch:")
    public void willEndSearch(UISearchDisplayController controller) {}
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayControllerDidEndSearch:")
    public void didEndSearch(UISearchDisplayController controller) {}
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:didLoadSearchResultsTableView:")
    public void didLoadSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:willUnloadSearchResultsTableView:")
    public void willUnloadSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:willShowSearchResultsTableView:")
    public void willShowSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:didShowSearchResultsTableView:")
    public void didShowSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:willHideSearchResultsTableView:")
    public void willHideSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:didHideSearchResultsTableView:")
    public void didHideSearchResults(UISearchDisplayController controller, UITableView tableView) {}
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:shouldReloadTableForSearchString:")
    public boolean shouldReloadForSearchString(UISearchDisplayController controller, String searchString) { return false; }
    /**
     * @deprecated Deprecated in iOS 8.0.
     */
    @Deprecated
    @NotImplemented("searchDisplayController:shouldReloadTableForSearchScope:")
    public boolean shouldReloadForSearchScope(UISearchDisplayController controller, @MachineSizedSInt long searchOption) { return false; }
    /*</methods>*/
}
